RafByteSink class

Inheritance

Constructors

RafByteSink(RandomAccessFile raf, {void onWrite(int count)?})

Properties

hashCode int
The hash code for this object.
no setterinherited
onWrite → void Function(int count)?
final
raf RandomAccessFile
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(List<int> chunk) → void
Adds chunked data to this sink.
override
addSlice(List<int> chunk, int start, int end, bool isLast) → void
Adds the next chunk to this.
inherited
close() → void
Closes the sink.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited